@@ -11,7 +11,7 @@ from devsecops_engine_tools.engine_sast.engine_secret.src.domain.model.gateway.g
 from devsecops_engine_tools.engine_core.src.domain.model.gateway.devops_platform_gateway import (
     DevopsPlatformGateway,
 )
-from devsecops_engine_tools.engine_sast.engine_secret.src.domain.model.gateway.git_gateway import (
+from devsecops_engine_tools.engine_utilities.git_cli.model.gateway.git_gateway import (
     GitGateway
 )
 
@@ -36,14 +36,20 @@ class SecretScan:
             files_pullrequest = self.git_gateway.get_files_pull_request(
                 self.devops_platform_gateway.get_variable("path_directory"),
                 self.devops_platform_gateway.get_variable("target_branch"),
+                config_tool.target_branches,
                 self.devops_platform_gateway.get_variable("source_branch"),
-                config_tool.message_info_engine_secret)
+                self.devops_platform_gateway.get_variable("access_token"),
+                self.devops_platform_gateway.get_variable("organization"),
+                self.devops_platform_gateway.get_variable("project_name"),
+                self.devops_platform_gateway.get_variable("repository"),
+                self.devops_platform_gateway.get_variable("repository_provider"))
             findings, file_path_findings = self.tool_gateway.run_tool_secret_scan(
                     files_pullrequest,
                     config_tool.exclude_path,
                     self.devops_platform_gateway.get_variable("os"),
                     self.devops_platform_gateway.get_variable("path_directory"),
-                    config_tool.number_threads
+                    config_tool.number_threads,
+                    self.devops_platform_gateway.get_variable("repository")
                     )
             finding_list = self.tool_deserialize.get_list_vulnerability(
                 findings,
