@@ -90,11 +90,11 @@ class ImportScanUserCase:
 
         logger.debug(f"search Engagement name: {request.engagement_name}")
         engagement = self.__rest_engagement.get_engagements(request.engagement_name)
-        if engagement.results == [] or any(engagement.name != request.engagement_name for engagement in engagement.results):
+        if engagement.results == [] or not any(engagement.name == request.engagement_name for engagement in engagement.results):
             engagement = self.__rest_engagement.post_engagement(request.engagement_name, product_id)
             logger.debug(f"Egagement created: {engagement.name}")
         else:
-            engagement = [engagement for engagement in engagement.results if engagement.product == product_id]
+            engagement = [engagement for engagement in engagement.results if engagement.product == product_id and engagement.name == request.engagement_name]
             if engagement:
                 logger.debug(f"Engagement found: {engagement[0].name} whit product id: {engagement[0].product}")
             else:
